Package: rashnu
Title: Balanced Sample Size and Power Calculation Tools
Version: 0.1.2
Authors@R: c(
    person("Sungho", "Choi", , "1213sam0@gmail.com", role = c("aut")),
    person("Gyeom", "Hwangbo", , "hbgyeom@gmail.com", role = c("ctb", "cre")),
    person("Zarathu", role = c("cph", "fnd"))
    )
Description: Implements sample size and power calculation methods with a focus on balance and fairness in study design, inspired by the Zoroastrian deity Rashnu, the judge who weighs truth. Supports survival analysis and various hypothesis testing frameworks.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: shiny, DT, stats
Suggests: covr, testthat (>= 3.0.0)
Config/testthat/edition: 3
URL: https://zarathucorp.github.io/rashnu/,
        https://github.com/zarathucorp/rashnu
BugReports: https://github.com/zarathucorp/rashnu/issues
NeedsCompilation: no
Packaged: 2025-07-22 05:29:43 UTC; gyeom.hwangbo
Author: Sungho Choi [aut],
  Gyeom Hwangbo [ctb, cre],
  Zarathu [cph, fnd]
Maintainer: Gyeom Hwangbo <hbgyeom@gmail.com>
Repository: CRAN
Date/Publication: 2025-07-23 08:00:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:19:09 UTC; unix
