# Generated by roxygen2: do not edit by hand

export(coxph_size)
export(k_mean_size)
export(k_prop_size)
export(lakatosSampleSize)
export(oneSurvSampleSize)
export(one_bino_size)
export(one_mean_size)
export(one_norm_size)
export(one_prop_size)
export(or_size)
export(pair_prop_size)
export(rashnuBasic)
export(sccs_size)
export(twoSurvSampleSizeNI)
export(two_mean_size)
export(two_prop_size)
import(shiny)
importFrom(DT,DTOutput)
importFrom(DT,datatable)
importFrom(DT,renderDT)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
